# gloe.utils

```{eval-rst}
.. automodule:: gloe.utils
   :members:
   :undoc-members:
   :show-inheritance:
```
```{eval-rst}
.. autovariable:: forget 
    :type: :code:`Transformer[Any, None]`
.. autovariable:: debug
    :no-value:
    :type: :code:`Transformer[T, T]`
```
